# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.01.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_top_users_response import ListTopUsersResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListTopUsersResponse(unittest.TestCase):
    """ListTopUsersResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListTopUsersResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_top_users_response.ListTopUsersResponse()  # noqa: E501
        if include_optional :
            return ListTopUsersResponse(
                top_users = [
                    agilicus_api.models.user_metrics.UserMetrics(
                        email = 'foo@example.com', 
                        count = 56, 
                        user_id = '0', )
                    ], 
                limit = 56
            )
        else :
            return ListTopUsersResponse(
                limit = 56,
        )

    def testListTopUsersResponse(self):
        """Test ListTopUsersResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.01.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class RuleV2(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'metadata': 'MetadataWithId',
        'spec': 'RuleSpec'
    }

    attribute_map = {
        'metadata': 'metadata',
        'spec': 'spec'
    }

    def __init__(self, metadata=None, spec=None, local_vars_configuration=None):  # noqa: E501
        """RuleV2 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._metadata = None
        self._spec = None
        self.discriminator = None

        if metadata is not None:
            self.metadata = metadata
        self.spec = spec

    @property
    def metadata(self):
        """Gets the metadata of this RuleV2.  # noqa: E501


        :return: The metadata of this RuleV2.  # noqa: E501
        :rtype: MetadataWithId
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this RuleV2.


        :param metadata: The metadata of this RuleV2.  # noqa: E501
        :type: MetadataWithId
        """

        self._metadata = metadata

    @property
    def spec(self):
        """Gets the spec of this RuleV2.  # noqa: E501


        :return: The spec of this RuleV2.  # noqa: E501
        :rtype: RuleSpec
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this RuleV2.


        :param spec: The spec of this RuleV2.  # noqa: E501
        :type: RuleSpec
        """
        if self.local_vars_configuration.client_side_validation and spec is None:  # noqa: E501
            raise ValueError("Invalid value for `spec`, must not be `None`")  # noqa: E501

        self._spec = spec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleV2):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RuleV2):
            return True

        return self.to_dict() != other.to_dict()
